@@ -3,11 +3,12 @@
 # :Author:    Ken Robbins <ken@kenrobbins.com>
 # :License:   MIT License
 # :Copyright: © 2015 Ken Robbins
-# :Copyright: © 2015, 2016, 2017 Lele Gaifax
+# :Copyright: © 2015, 2016, 2017, 2018 Lele Gaifax
 #
 
 from calendar import timegm
 from datetime import date, datetime, time
+import io
 import math
 import uuid
 
@@ -244,7 +245,7 @@ def test_decimal(dumps, loads):
 def test_datetime_mode_dumps(dumps):
     import pytz
 
-    d = datetime.utcnow()
+    d = datetime(2018, 1, 2, 11, 56, 19, 854440)
     dstr = d.isoformat()
 
     with pytest.raises(TypeError):
@@ -290,7 +291,7 @@ def test_datetime_mode_dumps(dumps):
         d, datetime_mode= rj.DM_UNIX_TIME | rj.DM_ONLY_SECONDS
     ) == str(d.timestamp()).split('.')[0]
 
-    d = datetime.now()
+    d = datetime(2018, 1, 2, 12, 56, 19, 854440)
 
     assert dumps(
         d, datetime_mode=rj.DM_ISO8601 | rj.DM_NAIVE_IS_UTC
@@ -552,7 +553,7 @@ def test_invalid_dumps_params(posargs, kwargs, dumps):
 @pytest.mark.unit
 def test_explicit_defaults_loads():
     assert rj.loads(
-        s='"foo"',
+        string='"foo"',
         object_hook=None,
         number_mode=None,
         datetime_mode=None,
@@ -562,6 +563,29 @@ def test_explicit_defaults_loads():
     ) == "foo"
 
 
+@pytest.mark.unit
+def test_explicit_defaults_load():
+    assert rj.load(
+        stream=io.StringIO('"foo"'),
+        object_hook=None,
+        number_mode=None,
+        datetime_mode=None,
+        uuid_mode=None,
+        parse_mode=None,
+        chunk_size=None,
+        allow_nan=True,
+    ) == "foo"
+
+
+@pytest.mark.unit
+def test_explicit_defaults_decoder():
+    assert rj.Decoder(
+        number_mode=None,
+        datetime_mode=None,
+        uuid_mode=None,
+        parse_mode=None)('"foo"') == "foo"
+
+
 @pytest.mark.unit
 def test_explicit_defaults_dumps():
     assert rj.dumps(
@@ -576,3 +600,51 @@ def test_explicit_defaults_dumps():
         uuid_mode=None,
         allow_nan=True,
     ) == '"foo"'
+
+
+@pytest.mark.unit
+def test_explicit_defaults_dump():
+    stream = io.StringIO()
+    assert rj.dump(
+        obj='foo',
+        stream=stream,
+        skipkeys=False,
+        ensure_ascii=True,
+        indent=None,
+        default=None,
+        sort_keys=False,
+        number_mode=None,
+        datetime_mode=None,
+        uuid_mode=None,
+        allow_nan=True,
+        chunk_size=None) is None
+    assert stream.getvalue() == '"foo"'
+
+
+@pytest.mark.unit
+def test_explicit_defaults_encoder():
+    assert rj.Encoder(
+        skip_invalid_keys=False,
+        ensure_ascii=True,
+        indent=None,
+        sort_keys=False,
+        number_mode=None,
+        datetime_mode=None,
+        uuid_mode=None)({'foo': 'bar'}) == '{"foo":"bar"}'
+
+
+@pytest.mark.unit
+def test_encoder_call():
+    o = {'foo': 'bar'}
+
+    result = rj.Encoder()(o)
+    assert result == '{"foo":"bar"}'
+    assert rj.Encoder()(o, None) == result
+
+    stream = io.StringIO()
+    assert rj.Encoder()(o, stream) is None
+    assert stream.getvalue() == result
+
+    stream = io.StringIO()
+    assert rj.Encoder()(o, stream=stream) is None
+    assert stream.getvalue() == result
